@@ -1,3 +1,11 @@
+#' @importFrom dplyr select
+#' @export
+select.navigatr_menu <- function(.data, ...) {
+  keys <- set_names(.data$key)
+  loc <- tidyselect::eval_select(expr(c(...)), keys)
+  vec_slice(.data, loc)
+}
+
 #' @importFrom dplyr select
 #' @export
 select.navigatr_item <- function(.data, ...) {
